@@ -1,6 +1,6 @@
 package Net::Bullfinch;
 {
-  $Net::Bullfinch::VERSION = '0.04';
+  $Net::Bullfinch::VERSION = '0.05';
 }
 use Moose;
 use MooseX::Params::Validate;
@@ -53,18 +53,19 @@ has 'timeout' => (
 
 
 sub send {
-    my ($self, $queue, $data, $queuename, $trace, $procby) = validated_list(\@_,
+    my ($self, $queue, $data, $queuename, $trace, $procby, $expire) = validated_list(\@_,
         request_queue         => { isa => 'Str' },
         request               => { isa => 'HashRef' },
         response_queue_suffix => { isa => 'Str', optional => 1 },
         trace                 => { isa => 'Bool', default => 0, optional => 1 },
-        process_by            => { isa => 'DateTime', optional => 1 }
+        process_by            => { isa => 'DateTime', optional => 1 },
+        expiration            => { isa => 'Int', optional => 1 }
     );
 
     my ($rname, $json) = $self->_prepare_request($data, $queuename, $trace, $procby);
     my $kes = $self->_client;
 
-    $kes->set($queue, $json);
+    $kes->set($queue, $json, $expire);
 
     my @items = ();
     while(1) {
@@ -145,7 +146,7 @@ Net::Bullfinch - Perl wrapper for talking with Bullfinch
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -208,7 +209,7 @@ back from Bullfinch.
 
 =head1 METHODS
 
-=head2 send( request_queue => $queue, request => \%data, response_queue_suffix => $response_name, process_by => $procby);
+=head2 send( request_queue => $queue, request => \%data, response_queue_suffix => $response_name, process_by => $procby, expiration => $expire);
 
 Send the request to the specified queue and await a response.  The data
 should be a hashref and the queuename (optional) will be appended to
@@ -223,6 +224,9 @@ arrayref to the caller.
 
 The optional C<process_by> must be an ISO 8601 date.
 
+The optional C<expiration> is the number of seconds this request should live
+in the queue before expiring.
+
 =head1 AUTHOR
 
 Cory G Watson <gphat@cpan.org>
